/**
 * @doc
 * @anue-package Anue.Bridge.Client
 * 這個類別實作了Web中與`<iframe/>`類型的[Bridge Server](->Anue.Bridge.AbstrctServerBridge)
 * 溝通時所使用的[Bridge Cient](Anue.Bridge.AbstractClientBridge)。
 *
 * 在使用前必須要將目標Bridge Server的對象（即iframe實體）放入建構子中進行初始化。
 *
 * ```Javascript
 * // 載入實作
 * import WebBridgeClient from 'anue-fe-sdk/web-bridge-client'
 *
 * // 取得frame實體
 * const portal = document.getElementById('protal')
 *
 * // 初始化
 * const client = new WebBridgeClient({
 *   target: protal
 * })
 *
 * // 確保已經連結
 * await client.attach()
 *
 * // 送出API請求
 * const apis = await client.request('common.handshake')
 * ```
 */
import Payload = Anue.Bridge.Payload;
import AbstractClientBridge from '@libraries/Bridge/Client.abstract';
export default class Client extends AbstractClientBridge {
    private mRequestTable;
    private mPushHandlers;
    private mWindow;
    protected listen: (message: MessageEvent) => void;
    private attachWindow;
    request: (request: any) => Promise<Payload<any>>;
    onPush: (apiName: Anue.Bridge.URI, fn: (args: Payload<any>) => void) => Client;
    attach: () => Promise<boolean>;
}
